#!/bin/sh

#-------- OpenHAB demo configuration files installer script
#-------- package based on work from pcloadletter.co.uk

DOWNLOAD_FILE="distribution-1.5.0-demo-configuration.zip"
DOWNLOAD_PATH="https://github.com/openhab/openhab/releases/download/v1.5.0"
EXTRACTED_FOLDER="OpenHAB-demo-configuration-1.5.0"
DOWNLOAD_URL="${DOWNLOAD_PATH}/${DOWNLOAD_FILE}"
DAEMON_USER="openhab"
FILES_GROUP="users"
INSTALL_FILES="${DOWNLOAD_URL}"
source /etc/profile
TEMP_FOLDER="`find / -maxdepth 2 -name '@tmp' | head -n 1`"
PRIMARY_VOLUME="/`echo $TEMP_FOLDER | cut -f2 -d'/'`"
INSTALL_DIR="/var/packages/OpenHAB/target"

preinst ()
{
  cd ${TEMP_FOLDER}
  for WGET_URL in ${INSTALL_FILES}
  do
    WGET_FILENAME="`echo ${WGET_URL} | sed -r "s%^.*/(.*)%\1%"`"
    [ -f ${TEMP_FOLDER}/${WGET_FILENAME} ] && rm ${TEMP_FOLDER}/${WGET_FILENAME}
    wget --no-check-certificate --output-document=${WGET_FILENAME} ${WGET_URL}
    if [[ $? != 0 ]]; then
      if [ -d ${PUBLIC_FOLDER} ] && [ -f ${PUBLIC_FOLDER}/${DOWNLOAD_FILE} ]; then
        cp ${PUBLIC_FOLDER}/${DOWNLOAD_FILE} ${TEMP_FOLDER}
      else     
        echo "There was a problem downloading ${WGET_FILENAME} from the official download link, "
        echo "which was \"${WGET_URL}\" "
        echo "Alternatively, you may download this file manually and place it in the 'public' shared folder. "
        exit 1
      fi
    fi
  done
  
  exit 0
}


postinst ()
{
  #extract main archive
  cd ${TEMP_FOLDER}
  unzip ${TEMP_FOLDER}/${DOWNLOAD_FILE} -d ${EXTRACTED_FOLDER} && rm ${TEMP_FOLDER}/${DOWNLOAD_FILE}
cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/* ${INSTALL_DIR}/
cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/addons/* ${INSTALL_DIR}/addons/
cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/configurations/* ${INSTALL_DIR}/configurations/
# replace demo.rules as TTS is not working with slow cpu's
#  cp ${SYNOPKG_PKGDEST}/demo.rules ${INSTALL_DIR}/configurations/rules/
#  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/etc/* ${INSTALL_DIR}/etc/
#  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/server/* ${INSTALL_DIR}/server/
#  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/sounds/* ${INSTALL_DIR}/sounds/
#  cp -r ${TEMP_FOLDER}/${EXTRACTED_FOLDER}/webapps/* ${INSTALL_DIR}/webapps/
    
  rmdir ${TEMP_FOLDER}/${EXTRACTED_FOLDER}

# change permission of demofiles: user of files: openhab with wx permissions
chown -R ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/*
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/items/demo.items
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/rules/demo.rules
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/scripts/demo.script
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/sitemaps/demo.sitemap
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/persistence/logging.persist
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/persistence/db4o.persist
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/persistence/exec.persist
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/configurations/persistence/rrd4j.persist
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/etc/*
chown ${DAEMON_USER}:${FILES_GROUP} ${INSTALL_DIR}/server/*
  
chmod -R u+x ${INSTALL_DIR}/*
chmod u+x ${INSTALL_DIR}/configurations/items/demo.items
chmod u+x ${INSTALL_DIR}/configurations/rules/demo.rules
chmod u+x ${INSTALL_DIR}/configurations/scripts/demo.script
chmod u+x ${INSTALL_DIR}/configurations/sitemaps/demo.sitemap
chmod u+x ${INSTALL_DIR}/configurations/persistence/logging.persist
chmod u+x ${INSTALL_DIR}/configurations/persistence/db4o.persist
chmod u+x ${INSTALL_DIR}/configurations/persistence/exec.persist
chmod u+x ${INSTALL_DIR}/configurations/persistence/rrd4j.persist
                  

  exit 0
}


preuninst ()
{
  #nothing to do
  exit 0
}


postuninst ()
{
  #remove addons
  rm ${INSTALL_DIR}/addons/org.openhab.persistence.rrd4j-1.4.0.jar
  rm ${INSTALL_DIR}/addons/org.openhab.persistence.logging-1.4.0.jar
  rm ${INSTALL_DIR}/addons/org.openhab.persistence.exec-1.4.0.jar
  rm ${INSTALL_DIR}/addons/org.openhab.io.multimedia.tts.freetts-1.4.0.jar
  rm ${INSTALL_DIR}/addons/org.openhab.binding.ntp-1.4.0.jar
  rm ${INSTALL_DIR}/addons/org.openhab.binding.http-1.4.0.jar
  # remove demo configuration
  rm ${INSTALL_DIR}/configurations/items/demo.items
  rm ${INSTALL_DIR}/configurations/rules/demo.rules
  rm ${INSTALL_DIR}/configurations/scripts/demo.script
  rm ${INSTALL_DIR}/configurations/sitemaps/demo.sitemap
#  rm ${INSTALL_DIR}/configurations/persistence/logging.persist
#  rm ${INSTALL_DIR}/configurations/persistence/db4o.persist
#  rm ${INSTALL_DIR}/configurations/persistence/exec.persist
#  rm ${INSTALL_DIR}/configurations/persistence/rrd4j.persist
  exit 0
}
